# SCRS LaTeX Thesis Template

<!--
# SPDX-FileCopyrightText: 2023-2024 Philip Bergmann <philip.bergmann@uni-wuerzburg.de>
# SPDX-License-Identifier: CC-BY-SA-4.0
-->

This template provides a scaffold for writing your thesis.
While layout changes are generally not a problem, please try to leave the title page as it is.

## Usage
- See the [LaTeX section in this file](#latex) for some hints on how to compile
- Please choose a license for your work; for more information, see [license.tex](license.tex)
- Keep the [hints for a good thesis](#common-mistakes-and-hints-for-a-good-thesis) in mind
- Please respect the disclosure policy for [AI generated content](#ai-generated-content)
- When submitting your thesis, remember to include a [declaration of authorship](#declaration-of-authorship)

## LaTeX
- The template is currently setup for only `lualatex`, `biblatex` and `biber`. Other LaTeX engines and bibliography tools should generally work as well, but will probably require adjusting the preamble and/or class file. If you do this, let us know, so we can try to include your word, so that the next person does not have to do it as well ;)
- The compilation is orchestrated by `latexmk`.

### Generic Instructions
- Install a TeX distribution. Development currently happens under Debian / TeXLive
    - Debian and probably most Debian-based distributions: `apt install texlive-full` (all-inclusive service, but a big download/install! If you do not have the space, you need to identify the individual packages yourself - but feel free to let us know.)
- If you rename `writeup.tex`, also adjust `@default_files` in `latexmkrc` accordingly.
- To compile, just run `latexmk` in the directory of the main `.tex` file and the `latexmkrc` file. It will automatically compile as often as needed and run `biber` as well, when required.

### VSCodium / VS Code
- James-Yu's LaTex Workshop ([GitHub](https://github.com/James-Yu/LaTeX-Workshop), [Open VSX](https://open-vsx.org/extension/James-Yu/latex-workshop)) works great, to get it to compile with `latexmk` using `latexmkrc`, set `"latex-workshop.latex.recipe.default"` to `"latexmk (latexmkrc)"` (already set in the `.vscode/settings.json` included with the template)
- You might also want to use valentjin's LTeX – LanguageTool grammar/spell checking extension ([GitHub](https://github.com/valentjn/vscode-ltex), [Open VSX](https://open-vsx.org/extension/valentjn/vscode-ltex)) together with LanguageTool for type and grammar checking.

## Common Mistakes and Hints for a Good Thesis

### Referencing
- When referring to something, it should be clear what exactly you are referring to. *cleveref* (`\cref{label here}` in the middle of sentences and `\Cref{label here}` at the beginning of a sentence) make it easy.
- For a figure or table, write `Figure 1`, with a capital letter `F` - even in the middle of a sentence.
- Equations are identified by parenthesis (round "brackets", e.g. `(2.1)`) and optionally a label prefix `Eq.` / `Equation` (*cleveref* includes it).

### Graphics
- When including drawings, plots, etc., include them as vector graphic (`eps`, `pdf`, ...) if at all possible (and reasonable).
    - Exporting a PDF from draw.io is not more complicated than exporting a raster image, but the result looks much better and stays sharp when zoomed in.
    - If possible with your plotting toolkit, you can also export your graphic as drawing commands for e.g. *pgf* - then with correct configuration the type face and font size will also match with the rest of the text. *Matplotlib* can do that, see its documentation [here](https://matplotlib.org/stable/users/explain/text/pgf.html). Note: This is typically more work and not strictly necessary.
    - A vector graphic is no longer reasonable if a recent computer takes a few seconds to render the resulting page. If the vector graphic is a plot, then with tools like *matplotlib* and *pgf*, it is possible to rasterize the plot lines while still keeping the axis, labels and legend as vector elements. If this is not easily possible, pre-render the graphic to a lossless raster format with sufficient resolution.
- Use raster images with lossless compression (`png`, ...) for screenshots and other images that were rastered in their original form.
- Use raster images with lossy compression (`jpeg`, ...) for pictures taken with a camera.

### Symbols and Equations
- All symbols that appear in equations (or elsewhere) must be properly explained.
- Symbol usage must be consistent throughout your writeup, e.g. don't use `x(t)` to refer to the baseband and the passband signal.

#### Text Within Math Mode
Note: Fonts and text rendering with or without LaTeX is seemingly pretty complicated, so some terms might not be 100% correct. The main goal of this section is however to avoid writing text in math mode, and I think for that it's sufficient ;) It applies as written when using the default font setup (serif / roman fonts)

- Sub- and superscripts that are not variables, i.e. are not stand-ins for numbers/expressions, shall be set upright in the math font family, e.g. `\mathrm{word}`. Examples:
    - if you have the radius of the Earth as `R_E`, the `E` shall not be cursive, because it does not replace something else (it's a name), so write `R_\mathrm{E}`
    - set the summation index cursive (that is, without any special markup): `\sum_{i=1}^{N} x_i` (the `_i` shall be replaced by 1, 2, ..., N and is therefore a variable that is set cursive)
- Words or abbreviations in equations that still act as symbols are set upright in the math font family, e.g. `\mathrm{velocity} = \frac{\mathrm{distance}}{\mathrm{time}}`. This also applies to subscripts, etc. Please note that `\mathrm` is very limited and does e.g. not support (i.e. eat) spaces.
- `\text{your text here}` is used when actual text is needed in math mode, e.g. in a `cases` environment with `\text{if\ } x >0` or `\text{otherwise}`

### Units and Quantities
- When writing quantities, use a package like `siunitx` (if possible) - then you don't have to deal with the typography yourself.
- Prefer quantity equations (equations that remain valid independent of the units, e.g. `\lambda = c / f`) and make sure the units work out. Avoid numerical-value equations (equations that depend on the quantities being expressed in specific units, e.g. `\lambda in m = 300 / f in MHz`). If numerical-value equations are required or very common, give the quantity equation beforehand.
- To label e.g. a column containing numeric values of a symbol, write `SYMBOL / UNIT`, or `SYMBOL in UNIT`, e.g. `SNR / dB`. The square brackets `[]` are used to indicate the unit of a symbol, e.g. `[SNR] = dB`. Ergo, `SNR [dB]` is nonsensical and wrong - even if commonly seen.
- More information about correctly dealing with units and equations can be found in the Rhode & Schwarz Brochure (in german, currently no other language version is known) [Der normgerechte Umgang mit Größen, Einheiten, und Gleichungen](https://scdn.rohde-schwarz.com/ur/pws/dl_downloads/pdm/cl_brochures_and_datasheets/brochure/5214_5061_61/Der_normgerechte_Umgang_mit_bro_de_5214-5061-61_v0600.pdf) ([IA](https://web.archive.org/web/20240304101932/https://scdn.rohde-schwarz.com/ur/pws/dl_downloads/pdm/cl_brochures_and_datasheets/brochure/5214_5061_61/Der_normgerechte_Umgang_mit_bro_de_5214-5061-61_v0600.pdf)) (Source: Search for *Einheiten* in the *Knowledge Center Downloads*)
    - Exception: `dBm` and friends are acceptable here, even if this document says these ITU abbreviations are to be avoided.

### Misc
- In English, you can use either
  - Title Case (capitalize most words, except for articles, coordinating conjunctions, and most short prepositions - unless they are at the beginning or end, e.g. `The Quick Brown Fox Jumps Over the Lazy Dog`; for more information see the [IEEE Editorial Style Manual](https://ieeeauthorcenter.ieee.org/wp-content/uploads/IEEE-Editorial-Style-Manual.pdf) ([IA](https://web.archive.org/web/20221024131621/http://ieeeauthorcenter.ieee.org/wp-content/uploads/IEEE-Editorial-Style-Manual.pdf)), section *A. Writing Parts of an Article*), or
  - normal case (like a normal English sentence, e.g. `The quick brown fox jumps over the lazy dog`).

## AI Generated Content

We ask you to follow the [submission guidelines from IEEE](https://journals.ieeeauthorcenter.ieee.org/become-an-ieee-journal-author/publishing-ethics/guidelines-and-policies/submission-and-peer-review-policies/#ai-generated-text), i.e.,

> The use of content generated by artificial intelligence (AI) in an article (including but not limited to text, figures, images, and code) shall be disclosed in the acknowledgments section [...]. The AI system used shall be identified, and specific sections of the article that use AI-generated content shall be identified and accompanied by a brief explanation regarding the level at which the AI system was used to generate the content.

> The use of AI systems for editing and grammar enhancement is common practice and, as such, is generally outside the intent of the above policy. In this case, disclosure as noted above is recommended.

## Declaration of authorship
**The following information is provided for your convenience only and not authoritative. Please refer to the ASPO or contact the examination office for authoritative information!**

You will need to include a declaration of authorship / Versicherung zur Leistungserbringung. Such a declaration is not part of this template.

A form you can use can be found on the examination office website:
- [English site](https://www.uni-wuerzburg.de/en/studying-at-jmu/examination-office/forms/) under *Theses/papers*
- [German site](https://www.uni-wuerzburg.de/studium/pruefungsamt/antragsformulare/) under *Abschlussarbeiten / Hausarbeiten*

It must be included as follows:
- If you submit your thesis via a digital medium (USB thumb drive, CD, ...), a paper version of the declaration is required. Please print out the form, sign it and submit it together with your thesis to the examination office.
- If you submit a printed & bound thesis, the declaration needs to be part of the bound work. It is recommended to place it at the back so that it can be easily found by the people in the examination office.

## License

The template consists of multiple files with different licenses. The license of each file is indicated either in its header or `<FILENAME>.license` companion file by `SPDX-License-Identifier`; the full text for each license may be found in the `LICENSES/` directory.

Generally, the template is available under libre licenses (LPPL, CC-BY), but the logos are *All Rights Reserved* with certain exceptions as specified in the `SPDX-License-Identifier` fields with the `WITH` clause. In short, use the logos only for the thesis and only as a student of JMU at our group.

This project strives for compatibility with the [REUSE specification](https://reuse.software/).

## Acknowledgements

Based on the Info 3 template - many thanks!
