#!/bin/sh
# Builds the document using the 'current' documentclass configuration
# SPDX-FileCopyrightText: 2025 Philip Bergmann <philip.bergmann@uni-wuerzburg.de>
# SPDX-License-Identifier: CC0-1.0
set -eu

# Absolute path to $0's directory, resolving all symlinks in the path
script_dir="$(dirname "$(readlink -f "$0")")"
readonly script_dir
cd -- "$script_dir"

# Config: job name
readonly default_jobname="writeup"
readonly jobname="${jobname:-$default_jobname}"

# latexmk sometimes has/had(?) problems with recognozing the source has changed
# after a git checkout/... and therefore decidied no rebuild was needed
# (even though it was!).
# We solve this by always deleting the PDF before the latexmk call in build.sh
rm -f -- "$jobname.pdf"

# Increase latex max line length, this makes it easier to read the log
# from https://tex.stackexchange.com/a/52994
export max_print_line=1000
export error_line=254
export half_error_line=238

# Run latexmk with the options specified in latexmkrc
latexmk "$jobname"
